#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="gif_properties.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six


class GifProperties(object):
    """Represents information about image in GIF format.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'background_color': 'str',
        'has_background_color': 'bool',
        'has_trailer': 'bool',
        'pixel_aspect_ratio': 'int'
    }

    attribute_map = {
        'background_color': 'BackgroundColor',
        'has_background_color': 'HasBackgroundColor',
        'has_trailer': 'HasTrailer',
        'pixel_aspect_ratio': 'PixelAspectRatio'
    }

    def __init__(self, background_color=None, has_background_color=None, has_trailer=None, pixel_aspect_ratio=None):
        """GifProperties - a model defined in Swagger"""
        super(GifProperties, self).__init__()

        self._background_color = None
        self._has_background_color = None
        self._has_trailer = None
        self._pixel_aspect_ratio = None

        if background_color is not None:
            self.background_color = background_color
        if has_background_color is not None:
            self.has_background_color = has_background_color
        if has_trailer is not None:
            self.has_trailer = has_trailer
        if pixel_aspect_ratio is not None:
            self.pixel_aspect_ratio = pixel_aspect_ratio

    @property
    def background_color(self):
        """Gets the background_color of this GifProperties.

        Gets or sets the background color.

        :return: The background_color of this GifProperties.
        :rtype: str
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """Sets the background_color of this GifProperties.

        Gets or sets the background color.

        :param background_color: The background_color of this GifProperties.
        :type: str
        """
        self._background_color = background_color

    @property
    def has_background_color(self):
        """Gets the has_background_color of this GifProperties.

        Gets or sets a value indicating whether background color is used.

        :return: The has_background_color of this GifProperties.
        :rtype: bool
        """
        return self._has_background_color

    @has_background_color.setter
    def has_background_color(self, has_background_color):
        """Sets the has_background_color of this GifProperties.

        Gets or sets a value indicating whether background color is used.

        :param has_background_color: The has_background_color of this GifProperties.
        :type: bool
        """
        if has_background_color is None:
            raise ValueError("Invalid value for `has_background_color`, must not be `None`")
        self._has_background_color = has_background_color

    @property
    def has_trailer(self):
        """Gets the has_trailer of this GifProperties.

        Gets or sets a value indicating whether image has trailer.

        :return: The has_trailer of this GifProperties.
        :rtype: bool
        """
        return self._has_trailer

    @has_trailer.setter
    def has_trailer(self, has_trailer):
        """Sets the has_trailer of this GifProperties.

        Gets or sets a value indicating whether image has trailer.

        :param has_trailer: The has_trailer of this GifProperties.
        :type: bool
        """
        if has_trailer is None:
            raise ValueError("Invalid value for `has_trailer`, must not be `None`")
        self._has_trailer = has_trailer

    @property
    def pixel_aspect_ratio(self):
        """Gets the pixel_aspect_ratio of this GifProperties.

        Gets or sets the pixel aspect ratio.

        :return: The pixel_aspect_ratio of this GifProperties.
        :rtype: int
        """
        return self._pixel_aspect_ratio

    @pixel_aspect_ratio.setter
    def pixel_aspect_ratio(self, pixel_aspect_ratio):
        """Sets the pixel_aspect_ratio of this GifProperties.

        Gets or sets the pixel aspect ratio.

        :param pixel_aspect_ratio: The pixel_aspect_ratio of this GifProperties.
        :type: int
        """
        if pixel_aspect_ratio is None:
            raise ValueError("Invalid value for `pixel_aspect_ratio`, must not be `None`")
        self._pixel_aspect_ratio = pixel_aspect_ratio

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GifProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="__init__.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

# import models into model package
from asposeimagingcloud.models.available_labels_list import AvailableLabelsList
from asposeimagingcloud.models.bmp_properties import BmpProperties
from asposeimagingcloud.models.detected_object import DetectedObject
from asposeimagingcloud.models.detected_object_list import DetectedObjectList
from asposeimagingcloud.models.dicom_properties import DicomProperties
from asposeimagingcloud.models.disc_usage import DiscUsage
from asposeimagingcloud.models.djvu_properties import DjvuProperties
from asposeimagingcloud.models.dng_properties import DngProperties
from asposeimagingcloud.models.eps_properties import EpsProperties
from asposeimagingcloud.models.error import Error
from asposeimagingcloud.models.error_details import ErrorDetails
from asposeimagingcloud.models.exif_data import ExifData
from asposeimagingcloud.models.file_versions import FileVersions
from asposeimagingcloud.models.files_list import FilesList
from asposeimagingcloud.models.files_upload_result import FilesUploadResult
from asposeimagingcloud.models.filter_properties_base import FilterPropertiesBase
from asposeimagingcloud.models.gif_properties import GifProperties
from asposeimagingcloud.models.image_duplicates import ImageDuplicates
from asposeimagingcloud.models.image_duplicates_set import ImageDuplicatesSet
from asposeimagingcloud.models.image_features import ImageFeatures
from asposeimagingcloud.models.imaging_response import ImagingResponse
from asposeimagingcloud.models.jfif_data import JfifData
from asposeimagingcloud.models.jpeg2000_properties import Jpeg2000Properties
from asposeimagingcloud.models.jpeg_properties import JpegProperties
from asposeimagingcloud.models.object_exist import ObjectExist
from asposeimagingcloud.models.odg_metadata import OdgMetadata
from asposeimagingcloud.models.odg_page import OdgPage
from asposeimagingcloud.models.odg_properties import OdgProperties
from asposeimagingcloud.models.png_properties import PngProperties
from asposeimagingcloud.models.psd_properties import PsdProperties
from asposeimagingcloud.models.rectangle import Rectangle
from asposeimagingcloud.models.search_context_status import SearchContextStatus
from asposeimagingcloud.models.search_result import SearchResult
from asposeimagingcloud.models.search_results_set import SearchResultsSet
from asposeimagingcloud.models.storage_exist import StorageExist
from asposeimagingcloud.models.storage_file import StorageFile
from asposeimagingcloud.models.svg_properties import SvgProperties
from asposeimagingcloud.models.tiff_frame import TiffFrame
from asposeimagingcloud.models.tiff_options import TiffOptions
from asposeimagingcloud.models.tiff_properties import TiffProperties
from asposeimagingcloud.models.web_p_properties import WebPProperties
from asposeimagingcloud.models.big_rectangular_filter_properties import BigRectangularFilterProperties
from asposeimagingcloud.models.bilateral_smoothing_filter_properties import BilateralSmoothingFilterProperties
from asposeimagingcloud.models.convolution_filter_properties import ConvolutionFilterProperties
from asposeimagingcloud.models.deconvolution_filter_properties import DeconvolutionFilterProperties
from asposeimagingcloud.models.file_version import FileVersion
from asposeimagingcloud.models.jpeg_exif_data import JpegExifData
from asposeimagingcloud.models.median_filter_properties import MedianFilterProperties
from asposeimagingcloud.models.small_rectangular_filter_properties import SmallRectangularFilterProperties
from asposeimagingcloud.models.gauss_wiener_filter_properties import GaussWienerFilterProperties
from asposeimagingcloud.models.gaussian_blur_filter_properties import GaussianBlurFilterProperties
from asposeimagingcloud.models.motion_wiener_filter_properties import MotionWienerFilterProperties
from asposeimagingcloud.models.sharpen_filter_properties import SharpenFilterProperties



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="dicom_properties.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six


class DicomProperties(object):
    """Represents information about image in dicom format.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'planar_configuration': 'int',
        'reds': 'str',
        'greens': 'str',
        'blues': 'str',
        'dicom_header_info_by_bytes': 'str',
        'signed_image': 'bool',
        'dicom_info': 'list[str]',
        'samples_per_pixel': 'int',
        'bits_allocated': 'int',
        'photo_interpretation': 'str',
        'width': 'int',
        'height': 'int',
        'window_centre': 'float',
        'window_width': 'float',
        'pixel_representation': 'int',
        'rescale_intercept': 'float',
        'rescale_slope': 'float',
        'number_of_frames': 'int',
        'is_little_endian': 'bool',
        'offset': 'int'
    }

    attribute_map = {
        'planar_configuration': 'PlanarConfiguration',
        'reds': 'Reds',
        'greens': 'Greens',
        'blues': 'Blues',
        'dicom_header_info_by_bytes': 'DicomHeaderInfoByBytes',
        'signed_image': 'SignedImage',
        'dicom_info': 'DicomInfo',
        'samples_per_pixel': 'SamplesPerPixel',
        'bits_allocated': 'BitsAllocated',
        'photo_interpretation': 'PhotoInterpretation',
        'width': 'Width',
        'height': 'Height',
        'window_centre': 'WindowCentre',
        'window_width': 'WindowWidth',
        'pixel_representation': 'PixelRepresentation',
        'rescale_intercept': 'RescaleIntercept',
        'rescale_slope': 'RescaleSlope',
        'number_of_frames': 'NumberOfFrames',
        'is_little_endian': 'IsLittleEndian',
        'offset': 'Offset'
    }

    def __init__(self, planar_configuration=None, reds=None, greens=None, blues=None, dicom_header_info_by_bytes=None, signed_image=None, dicom_info=None, samples_per_pixel=None, bits_allocated=None, photo_interpretation=None, width=None, height=None, window_centre=None, window_width=None, pixel_representation=None, rescale_intercept=None, rescale_slope=None, number_of_frames=None, is_little_endian=None, offset=None):
        """DicomProperties - a model defined in Swagger"""
        super(DicomProperties, self).__init__()

        self._planar_configuration = None
        self._reds = None
        self._greens = None
        self._blues = None
        self._dicom_header_info_by_bytes = None
        self._signed_image = None
        self._dicom_info = None
        self._samples_per_pixel = None
        self._bits_allocated = None
        self._photo_interpretation = None
        self._width = None
        self._height = None
        self._window_centre = None
        self._window_width = None
        self._pixel_representation = None
        self._rescale_intercept = None
        self._rescale_slope = None
        self._number_of_frames = None
        self._is_little_endian = None
        self._offset = None

        if planar_configuration is not None:
            self.planar_configuration = planar_configuration
        if reds is not None:
            self.reds = reds
        if greens is not None:
            self.greens = greens
        if blues is not None:
            self.blues = blues
        if dicom_header_info_by_bytes is not None:
            self.dicom_header_info_by_bytes = dicom_header_info_by_bytes
        if signed_image is not None:
            self.signed_image = signed_image
        if dicom_info is not None:
            self.dicom_info = dicom_info
        if samples_per_pixel is not None:
            self.samples_per_pixel = samples_per_pixel
        if bits_allocated is not None:
            self.bits_allocated = bits_allocated
        if photo_interpretation is not None:
            self.photo_interpretation = photo_interpretation
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if window_centre is not None:
            self.window_centre = window_centre
        if window_width is not None:
            self.window_width = window_width
        if pixel_representation is not None:
            self.pixel_representation = pixel_representation
        if rescale_intercept is not None:
            self.rescale_intercept = rescale_intercept
        if rescale_slope is not None:
            self.rescale_slope = rescale_slope
        if number_of_frames is not None:
            self.number_of_frames = number_of_frames
        if is_little_endian is not None:
            self.is_little_endian = is_little_endian
        if offset is not None:
            self.offset = offset

    @property
    def planar_configuration(self):
        """Gets the planar_configuration of this DicomProperties.

        Gets or sets the planar configuration.

        :return: The planar_configuration of this DicomProperties.
        :rtype: int
        """
        return self._planar_configuration

    @planar_configuration.setter
    def planar_configuration(self, planar_configuration):
        """Sets the planar_configuration of this DicomProperties.

        Gets or sets the planar configuration.

        :param planar_configuration: The planar_configuration of this DicomProperties.
        :type: int
        """
        if planar_configuration is None:
            raise ValueError("Invalid value for `planar_configuration`, must not be `None`")
        self._planar_configuration = planar_configuration

    @property
    def reds(self):
        """Gets the reds of this DicomProperties.

        Gets or sets the array of red colors.

        :return: The reds of this DicomProperties.
        :rtype: str
        """
        return self._reds

    @reds.setter
    def reds(self, reds):
        """Sets the reds of this DicomProperties.

        Gets or sets the array of red colors.

        :param reds: The reds of this DicomProperties.
        :type: str
        """
        if reds is not None and not re.search('^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', reds):
            raise ValueError("Invalid value for `reds`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")
        self._reds = reds

    @property
    def greens(self):
        """Gets the greens of this DicomProperties.

        Gets or sets the array of green colors.

        :return: The greens of this DicomProperties.
        :rtype: str
        """
        return self._greens

    @greens.setter
    def greens(self, greens):
        """Sets the greens of this DicomProperties.

        Gets or sets the array of green colors.

        :param greens: The greens of this DicomProperties.
        :type: str
        """
        if greens is not None and not re.search('^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', greens):
            raise ValueError("Invalid value for `greens`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")
        self._greens = greens

    @property
    def blues(self):
        """Gets the blues of this DicomProperties.

        Gets or sets the array of blue colors.

        :return: The blues of this DicomProperties.
        :rtype: str
        """
        return self._blues

    @blues.setter
    def blues(self, blues):
        """Sets the blues of this DicomProperties.

        Gets or sets the array of blue colors.

        :param blues: The blues of this DicomProperties.
        :type: str
        """
        if blues is not None and not re.search('^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', blues):
            raise ValueError("Invalid value for `blues`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")
        self._blues = blues

    @property
    def dicom_header_info_by_bytes(self):
        """Gets the dicom_header_info_by_bytes of this DicomProperties.

        Gets or sets the header information by bytes.

        :return: The dicom_header_info_by_bytes of this DicomProperties.
        :rtype: str
        """
        return self._dicom_header_info_by_bytes

    @dicom_header_info_by_bytes.setter
    def dicom_header_info_by_bytes(self, dicom_header_info_by_bytes):
        """Sets the dicom_header_info_by_bytes of this DicomProperties.

        Gets or sets the header information by bytes.

        :param dicom_header_info_by_bytes: The dicom_header_info_by_bytes of this DicomProperties.
        :type: str
        """
        if dicom_header_info_by_bytes is not None and not re.search('^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', dicom_header_info_by_bytes):
            raise ValueError("Invalid value for `dicom_header_info_by_bytes`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")
        self._dicom_header_info_by_bytes = dicom_header_info_by_bytes

    @property
    def signed_image(self):
        """Gets the signed_image of this DicomProperties.

        Gets or sets a value indicating whether it's a signed image.

        :return: The signed_image of this DicomProperties.
        :rtype: bool
        """
        return self._signed_image

    @signed_image.setter
    def signed_image(self, signed_image):
        """Sets the signed_image of this DicomProperties.

        Gets or sets a value indicating whether it's a signed image.

        :param signed_image: The signed_image of this DicomProperties.
        :type: bool
        """
        if signed_image is None:
            raise ValueError("Invalid value for `signed_image`, must not be `None`")
        self._signed_image = signed_image

    @property
    def dicom_info(self):
        """Gets the dicom_info of this DicomProperties.

        Gets or sets the header information of the DICOM file.

        :return: The dicom_info of this DicomProperties.
        :rtype: list[str]
        """
        return self._dicom_info

    @dicom_info.setter
    def dicom_info(self, dicom_info):
        """Sets the dicom_info of this DicomProperties.

        Gets or sets the header information of the DICOM file.

        :param dicom_info: The dicom_info of this DicomProperties.
        :type: list[str]
        """
        self._dicom_info = dicom_info

    @property
    def samples_per_pixel(self):
        """Gets the samples_per_pixel of this DicomProperties.

        Gets or sets samples per pixel count.

        :return: The samples_per_pixel of this DicomProperties.
        :rtype: int
        """
        return self._samples_per_pixel

    @samples_per_pixel.setter
    def samples_per_pixel(self, samples_per_pixel):
        """Sets the samples_per_pixel of this DicomProperties.

        Gets or sets samples per pixel count.

        :param samples_per_pixel: The samples_per_pixel of this DicomProperties.
        :type: int
        """
        if samples_per_pixel is None:
            raise ValueError("Invalid value for `samples_per_pixel`, must not be `None`")
        self._samples_per_pixel = samples_per_pixel

    @property
    def bits_allocated(self):
        """Gets the bits_allocated of this DicomProperties.

        Gets or sets allocated bits count.

        :return: The bits_allocated of this DicomProperties.
        :rtype: int
        """
        return self._bits_allocated

    @bits_allocated.setter
    def bits_allocated(self, bits_allocated):
        """Sets the bits_allocated of this DicomProperties.

        Gets or sets allocated bits count.

        :param bits_allocated: The bits_allocated of this DicomProperties.
        :type: int
        """
        if bits_allocated is None:
            raise ValueError("Invalid value for `bits_allocated`, must not be `None`")
        self._bits_allocated = bits_allocated

    @property
    def photo_interpretation(self):
        """Gets the photo_interpretation of this DicomProperties.

        Gets or sets the photo interpretation.

        :return: The photo_interpretation of this DicomProperties.
        :rtype: str
        """
        return self._photo_interpretation

    @photo_interpretation.setter
    def photo_interpretation(self, photo_interpretation):
        """Sets the photo_interpretation of this DicomProperties.

        Gets or sets the photo interpretation.

        :param photo_interpretation: The photo_interpretation of this DicomProperties.
        :type: str
        """
        self._photo_interpretation = photo_interpretation

    @property
    def width(self):
        """Gets the width of this DicomProperties.

        Gets or sets the width.

        :return: The width of this DicomProperties.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this DicomProperties.

        Gets or sets the width.

        :param width: The width of this DicomProperties.
        :type: int
        """
        if width is None:
            raise ValueError("Invalid value for `width`, must not be `None`")
        self._width = width

    @property
    def height(self):
        """Gets the height of this DicomProperties.

        Gets or sets the height.

        :return: The height of this DicomProperties.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this DicomProperties.

        Gets or sets the height.

        :param height: The height of this DicomProperties.
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")
        self._height = height

    @property
    def window_centre(self):
        """Gets the window_centre of this DicomProperties.

        Gets or sets the window centre.

        :return: The window_centre of this DicomProperties.
        :rtype: float
        """
        return self._window_centre

    @window_centre.setter
    def window_centre(self, window_centre):
        """Sets the window_centre of this DicomProperties.

        Gets or sets the window centre.

        :param window_centre: The window_centre of this DicomProperties.
        :type: float
        """
        if window_centre is None:
            raise ValueError("Invalid value for `window_centre`, must not be `None`")
        self._window_centre = window_centre

    @property
    def window_width(self):
        """Gets the window_width of this DicomProperties.

        Gets or sets the width of the window.

        :return: The window_width of this DicomProperties.
        :rtype: float
        """
        return self._window_width

    @window_width.setter
    def window_width(self, window_width):
        """Sets the window_width of this DicomProperties.

        Gets or sets the width of the window.

        :param window_width: The window_width of this DicomProperties.
        :type: float
        """
        if window_width is None:
            raise ValueError("Invalid value for `window_width`, must not be `None`")
        self._window_width = window_width

    @property
    def pixel_representation(self):
        """Gets the pixel_representation of this DicomProperties.

        Gets or sets data representation of the pixel samples.

        :return: The pixel_representation of this DicomProperties.
        :rtype: int
        """
        return self._pixel_representation

    @pixel_representation.setter
    def pixel_representation(self, pixel_representation):
        """Sets the pixel_representation of this DicomProperties.

        Gets or sets data representation of the pixel samples.

        :param pixel_representation: The pixel_representation of this DicomProperties.
        :type: int
        """
        if pixel_representation is None:
            raise ValueError("Invalid value for `pixel_representation`, must not be `None`")
        self._pixel_representation = pixel_representation

    @property
    def rescale_intercept(self):
        """Gets the rescale_intercept of this DicomProperties.

        Gets or sets a value of the rescale intercept.

        :return: The rescale_intercept of this DicomProperties.
        :rtype: float
        """
        return self._rescale_intercept

    @rescale_intercept.setter
    def rescale_intercept(self, rescale_intercept):
        """Sets the rescale_intercept of this DicomProperties.

        Gets or sets a value of the rescale intercept.

        :param rescale_intercept: The rescale_intercept of this DicomProperties.
        :type: float
        """
        if rescale_intercept is None:
            raise ValueError("Invalid value for `rescale_intercept`, must not be `None`")
        self._rescale_intercept = rescale_intercept

    @property
    def rescale_slope(self):
        """Gets the rescale_slope of this DicomProperties.

        Gets or sets a value of the rescale slope.

        :return: The rescale_slope of this DicomProperties.
        :rtype: float
        """
        return self._rescale_slope

    @rescale_slope.setter
    def rescale_slope(self, rescale_slope):
        """Sets the rescale_slope of this DicomProperties.

        Gets or sets a value of the rescale slope.

        :param rescale_slope: The rescale_slope of this DicomProperties.
        :type: float
        """
        if rescale_slope is None:
            raise ValueError("Invalid value for `rescale_slope`, must not be `None`")
        self._rescale_slope = rescale_slope

    @property
    def number_of_frames(self):
        """Gets the number_of_frames of this DicomProperties.

        Gets or sets the number of frames.

        :return: The number_of_frames of this DicomProperties.
        :rtype: int
        """
        return self._number_of_frames

    @number_of_frames.setter
    def number_of_frames(self, number_of_frames):
        """Sets the number_of_frames of this DicomProperties.

        Gets or sets the number of frames.

        :param number_of_frames: The number_of_frames of this DicomProperties.
        :type: int
        """
        if number_of_frames is None:
            raise ValueError("Invalid value for `number_of_frames`, must not be `None`")
        self._number_of_frames = number_of_frames

    @property
    def is_little_endian(self):
        """Gets the is_little_endian of this DicomProperties.

        Indicates if DICOM image has little endian byte order.

        :return: The is_little_endian of this DicomProperties.
        :rtype: bool
        """
        return self._is_little_endian

    @is_little_endian.setter
    def is_little_endian(self, is_little_endian):
        """Sets the is_little_endian of this DicomProperties.

        Indicates if DICOM image has little endian byte order.

        :param is_little_endian: The is_little_endian of this DicomProperties.
        :type: bool
        """
        if is_little_endian is None:
            raise ValueError("Invalid value for `is_little_endian`, must not be `None`")
        self._is_little_endian = is_little_endian

    @property
    def offset(self):
        """Gets the offset of this DicomProperties.

        Gets or sets the offset.

        :return: The offset of this DicomProperties.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this DicomProperties.

        Gets or sets the offset.

        :param offset: The offset of this DicomProperties.
        :type: int
        """
        if offset is None:
            raise ValueError("Invalid value for `offset`, must not be `None`")
        self._offset = offset

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DicomProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="get_image_frame_request.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from asposeimagingcloud.models.requests.imaging_request import ImagingRequest
from asposeimagingcloud.models.requests.http_request import HttpRequest


class GetImageFrameRequest(ImagingRequest):
    """
    Request model for get_image_frame operation.
    Initializes a new instance.

    :param name Filename of image.
    :param frame_id Number of a frame.
    :param new_width New width.
    :param new_height New height.
    :param x X position of start point for cropping rectangle.
    :param y Y position of start point for cropping rectangle.
    :param rect_width Width of cropping rectangle.
    :param rect_height Height of cropping rectangle.
    :param rotate_flip_method RotateFlip method (Rotate180FlipNone, Rotate180FlipX, Rotate180FlipXY, Rotate180FlipY, Rotate270FlipNone, Rotate270FlipX, Rotate270FlipXY, Rotate270FlipY, Rotate90FlipNone, Rotate90FlipX, Rotate90FlipXY, Rotate90FlipY, RotateNoneFlipNone, RotateNoneFlipX, RotateNoneFlipXY, RotateNoneFlipY). Default is RotateNoneFlipNone.
    :param save_other_frames If result will include all other frames or just a specified frame.
    :param folder Folder with image to process.
    :param storage Your Aspose Cloud Storage name.
    """

    def __init__(self, name, frame_id, new_width=None, new_height=None, x=None, y=None, rect_width=None, rect_height=None, rotate_flip_method=None, save_other_frames=None, folder=None, storage=None):
        ImagingRequest.__init__(self)
        self.name = name
        self.frame_id = frame_id
        self.new_width = new_width
        self.new_height = new_height
        self.x = x
        self.y = y
        self.rect_width = rect_width
        self.rect_height = rect_height
        self.rotate_flip_method = rotate_flip_method
        self.save_other_frames = save_other_frames
        self.folder = folder
        self.storage = storage

    def to_http_info(self, config):
        """
        Prepares initial info for HTTP request

        :param config: Imaging API configuration
        :type: asposeimagingcloud.Configuration
        :return: http_request configured http request
        :rtype: Configuration.models.requests.HttpRequest
        """
        # verify the required parameter 'name' is set
        if self.name is None:
            raise ValueError("Missing the required parameter `name` when calling `get_image_frame`")
        # verify the required parameter 'frame_id' is set
        if self.frame_id is None:
            raise ValueError("Missing the required parameter `frame_id` when calling `get_image_frame`")

        collection_formats = {}
        path = '/imaging/{name}/frames/{frameId}'
        path_params = {}
        if self.name is not None:
            path_params[self._lowercase_first_letter('name')] = self.name
        if self.frame_id is not None:
            path_params[self._lowercase_first_letter('frameId')] = self.frame_id

        query_params = []
        if self._lowercase_first_letter('newWidth') in path:
            path = path.replace('{' + self._lowercase_first_letter('newWidth' + '}'), self.new_width if self.new_width is not None else '')
        else:
            if self.new_width is not None:
                query_params.append((self._lowercase_first_letter('newWidth'), self.new_width))
        if self._lowercase_first_letter('newHeight') in path:
            path = path.replace('{' + self._lowercase_first_letter('newHeight' + '}'), self.new_height if self.new_height is not None else '')
        else:
            if self.new_height is not None:
                query_params.append((self._lowercase_first_letter('newHeight'), self.new_height))
        if self._lowercase_first_letter('x') in path:
            path = path.replace('{' + self._lowercase_first_letter('x' + '}'), self.x if self.x is not None else '')
        else:
            if self.x is not None:
                query_params.append((self._lowercase_first_letter('x'), self.x))
        if self._lowercase_first_letter('y') in path:
            path = path.replace('{' + self._lowercase_first_letter('y' + '}'), self.y if self.y is not None else '')
        else:
            if self.y is not None:
                query_params.append((self._lowercase_first_letter('y'), self.y))
        if self._lowercase_first_letter('rectWidth') in path:
            path = path.replace('{' + self._lowercase_first_letter('rectWidth' + '}'), self.rect_width if self.rect_width is not None else '')
        else:
            if self.rect_width is not None:
                query_params.append((self._lowercase_first_letter('rectWidth'), self.rect_width))
        if self._lowercase_first_letter('rectHeight') in path:
            path = path.replace('{' + self._lowercase_first_letter('rectHeight' + '}'), self.rect_height if self.rect_height is not None else '')
        else:
            if self.rect_height is not None:
                query_params.append((self._lowercase_first_letter('rectHeight'), self.rect_height))
        if self._lowercase_first_letter('rotateFlipMethod') in path:
            path = path.replace('{' + self._lowercase_first_letter('rotateFlipMethod' + '}'), self.rotate_flip_method if self.rotate_flip_method is not None else '')
        else:
            if self.rotate_flip_method is not None:
                query_params.append((self._lowercase_first_letter('rotateFlipMethod'), self.rotate_flip_method))
        if self._lowercase_first_letter('saveOtherFrames') in path:
            path = path.replace('{' + self._lowercase_first_letter('saveOtherFrames' + '}'), self.save_other_frames if self.save_other_frames is not None else '')
        else:
            if self.save_other_frames is not None:
                query_params.append((self._lowercase_first_letter('saveOtherFrames'), self.save_other_frames))
        if self._lowercase_first_letter('folder') in path:
            path = path.replace('{' + self._lowercase_first_letter('folder' + '}'), self.folder if self.folder is not None else '')
        else:
            if self.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), self.folder))
        if self._lowercase_first_letter('storage') in path:
            path = path.replace('{' + self._lowercase_first_letter('storage' + '}'), self.storage if self.storage is not None else '')
        else:
            if self.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), self.storage))

        header_params = {}

        form_params = []
        local_var_files = []

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'multipart/form-data' if form_params else self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        return HttpRequest(path, path_params, query_params, header_params, form_params, body_params, local_var_files,
                           collection_formats, auth_settings)



from asposeimagingcloud.models.requests.add_search_image_request import AddSearchImageRequest
from asposeimagingcloud.models.requests.append_tiff_request import AppendTiffRequest
from asposeimagingcloud.models.requests.compare_images_request import CompareImagesRequest
from asposeimagingcloud.models.requests.convert_image_request import ConvertImageRequest
from asposeimagingcloud.models.requests.convert_tiff_to_fax_request import ConvertTiffToFaxRequest
from asposeimagingcloud.models.requests.copy_file_request import CopyFileRequest
from asposeimagingcloud.models.requests.copy_folder_request import CopyFolderRequest
from asposeimagingcloud.models.requests.create_converted_image_request import CreateConvertedImageRequest
from asposeimagingcloud.models.requests.create_cropped_image_request import CreateCroppedImageRequest
from asposeimagingcloud.models.requests.create_deskewed_image_request import CreateDeskewedImageRequest
from asposeimagingcloud.models.requests.create_fax_tiff_request import CreateFaxTiffRequest
from asposeimagingcloud.models.requests.create_folder_request import CreateFolderRequest
from asposeimagingcloud.models.requests.create_grayscaled_image_request import CreateGrayscaledImageRequest
from asposeimagingcloud.models.requests.create_image_features_request import CreateImageFeaturesRequest
from asposeimagingcloud.models.requests.create_image_frame_range_request import CreateImageFrameRangeRequest
from asposeimagingcloud.models.requests.create_image_frame_request import CreateImageFrameRequest
from asposeimagingcloud.models.requests.create_image_search_request import CreateImageSearchRequest
from asposeimagingcloud.models.requests.create_image_tag_request import CreateImageTagRequest
from asposeimagingcloud.models.requests.create_modified_bmp_request import CreateModifiedBmpRequest
from asposeimagingcloud.models.requests.create_modified_emf_request import CreateModifiedEmfRequest
from asposeimagingcloud.models.requests.create_modified_gif_request import CreateModifiedGifRequest
from asposeimagingcloud.models.requests.create_modified_jpeg2000_request import CreateModifiedJpeg2000Request
from asposeimagingcloud.models.requests.create_modified_jpeg_request import CreateModifiedJpegRequest
from asposeimagingcloud.models.requests.create_modified_psd_request import CreateModifiedPsdRequest
from asposeimagingcloud.models.requests.create_modified_svg_request import CreateModifiedSvgRequest
from asposeimagingcloud.models.requests.create_modified_tiff_request import CreateModifiedTiffRequest
from asposeimagingcloud.models.requests.create_modified_web_p_request import CreateModifiedWebPRequest
from asposeimagingcloud.models.requests.create_modified_wmf_request import CreateModifiedWmfRequest
from asposeimagingcloud.models.requests.create_object_bounds_request import CreateObjectBoundsRequest
from asposeimagingcloud.models.requests.create_resized_image_request import CreateResizedImageRequest
from asposeimagingcloud.models.requests.create_rotate_flipped_image_request import CreateRotateFlippedImageRequest
from asposeimagingcloud.models.requests.create_updated_image_request import CreateUpdatedImageRequest
from asposeimagingcloud.models.requests.create_visual_object_bounds_request import CreateVisualObjectBoundsRequest
from asposeimagingcloud.models.requests.create_web_site_image_features_request import CreateWebSiteImageFeaturesRequest
from asposeimagingcloud.models.requests.crop_image_request import CropImageRequest
from asposeimagingcloud.models.requests.delete_file_request import DeleteFileRequest
from asposeimagingcloud.models.requests.delete_folder_request import DeleteFolderRequest
from asposeimagingcloud.models.requests.delete_image_features_request import DeleteImageFeaturesRequest
from asposeimagingcloud.models.requests.delete_image_search_request import DeleteImageSearchRequest
from asposeimagingcloud.models.requests.delete_search_image_request import DeleteSearchImageRequest
from asposeimagingcloud.models.requests.deskew_image_request import DeskewImageRequest
from asposeimagingcloud.models.requests.download_file_request import DownloadFileRequest
from asposeimagingcloud.models.requests.extract_image_features_request import ExtractImageFeaturesRequest
from asposeimagingcloud.models.requests.extract_image_frame_properties_request import ExtractImageFramePropertiesRequest
from asposeimagingcloud.models.requests.extract_image_properties_request import ExtractImagePropertiesRequest
from asposeimagingcloud.models.requests.filter_effect_image_request import FilterEffectImageRequest
from asposeimagingcloud.models.requests.find_images_by_tags_request import FindImagesByTagsRequest
from asposeimagingcloud.models.requests.find_image_duplicates_request import FindImageDuplicatesRequest
from asposeimagingcloud.models.requests.find_similar_images_request import FindSimilarImagesRequest
from asposeimagingcloud.models.requests.get_available_labels_request import GetAvailableLabelsRequest
from asposeimagingcloud.models.requests.get_disc_usage_request import GetDiscUsageRequest
from asposeimagingcloud.models.requests.get_files_list_request import GetFilesListRequest
from asposeimagingcloud.models.requests.get_file_versions_request import GetFileVersionsRequest
from asposeimagingcloud.models.requests.get_image_features_request import GetImageFeaturesRequest
from asposeimagingcloud.models.requests.get_image_frame_properties_request import GetImageFramePropertiesRequest
from asposeimagingcloud.models.requests.get_image_frame_range_request import GetImageFrameRangeRequest
from asposeimagingcloud.models.requests.get_image_frame_request import GetImageFrameRequest
from asposeimagingcloud.models.requests.get_image_properties_request import GetImagePropertiesRequest
from asposeimagingcloud.models.requests.get_image_search_status_request import GetImageSearchStatusRequest
from asposeimagingcloud.models.requests.get_object_bounds_request import GetObjectBoundsRequest
from asposeimagingcloud.models.requests.get_search_image_request import GetSearchImageRequest
from asposeimagingcloud.models.requests.get_visual_object_bounds_request import GetVisualObjectBoundsRequest
from asposeimagingcloud.models.requests.grayscale_image_request import GrayscaleImageRequest
from asposeimagingcloud.models.requests.http_request import HttpRequest
from asposeimagingcloud.models.requests.imaging_request import ImagingRequest
from asposeimagingcloud.models.requests.modify_bmp_request import ModifyBmpRequest
from asposeimagingcloud.models.requests.modify_emf_request import ModifyEmfRequest
from asposeimagingcloud.models.requests.modify_gif_request import ModifyGifRequest
from asposeimagingcloud.models.requests.modify_jpeg2000_request import ModifyJpeg2000Request
from asposeimagingcloud.models.requests.modify_jpeg_request import ModifyJpegRequest
from asposeimagingcloud.models.requests.modify_psd_request import ModifyPsdRequest
from asposeimagingcloud.models.requests.modify_svg_request import ModifySvgRequest
from asposeimagingcloud.models.requests.modify_tiff_request import ModifyTiffRequest
from asposeimagingcloud.models.requests.modify_web_p_request import ModifyWebPRequest
from asposeimagingcloud.models.requests.modify_wmf_request import ModifyWmfRequest
from asposeimagingcloud.models.requests.move_file_request import MoveFileRequest
from asposeimagingcloud.models.requests.move_folder_request import MoveFolderRequest
from asposeimagingcloud.models.requests.object_exists_request import ObjectExistsRequest
from asposeimagingcloud.models.requests.resize_image_request import ResizeImageRequest
from asposeimagingcloud.models.requests.rotate_flip_image_request import RotateFlipImageRequest
from asposeimagingcloud.models.requests.storage_exists_request import StorageExistsRequest
from asposeimagingcloud.models.requests.update_image_features_request import UpdateImageFeaturesRequest
from asposeimagingcloud.models.requests.update_image_request import UpdateImageRequest
from asposeimagingcloud.models.requests.update_search_image_request import UpdateSearchImageRequest
from asposeimagingcloud.models.requests.upload_file_request import UploadFileRequest




#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="jpeg_properties.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six

from asposeimagingcloud.models.jfif_data import JfifData
from asposeimagingcloud.models.jpeg_exif_data import JpegExifData


class JpegProperties(object):
    """Represents information about image in JPEG format.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'jpeg_exif_data': 'JpegExifData',
        'jpeg_jfif_data': 'JfifData'
    }

    attribute_map = {
        'comment': 'Comment',
        'jpeg_exif_data': 'JpegExifData',
        'jpeg_jfif_data': 'JpegJfifData'
    }

    def __init__(self, comment=None, jpeg_exif_data=None, jpeg_jfif_data=None):
        """JpegProperties - a model defined in Swagger"""
        super(JpegProperties, self).__init__()

        self._comment = None
        self._jpeg_exif_data = None
        self._jpeg_jfif_data = None

        if comment is not None:
            self.comment = comment
        if jpeg_exif_data is not None:
            self.jpeg_exif_data = jpeg_exif_data
        if jpeg_jfif_data is not None:
            self.jpeg_jfif_data = jpeg_jfif_data

    @property
    def comment(self):
        """Gets the comment of this JpegProperties.

        Gets or sets the comment.

        :return: The comment of this JpegProperties.
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this JpegProperties.

        Gets or sets the comment.

        :param comment: The comment of this JpegProperties.
        :type: str
        """
        self._comment = comment

    @property
    def jpeg_exif_data(self):
        """Gets the jpeg_exif_data of this JpegProperties.

        Gets or sets the JPEG EXIF data.

        :return: The jpeg_exif_data of this JpegProperties.
        :rtype: JpegExifData
        """
        return self._jpeg_exif_data

    @jpeg_exif_data.setter
    def jpeg_exif_data(self, jpeg_exif_data):
        """Sets the jpeg_exif_data of this JpegProperties.

        Gets or sets the JPEG EXIF data.

        :param jpeg_exif_data: The jpeg_exif_data of this JpegProperties.
        :type: JpegExifData
        """
        self._jpeg_exif_data = jpeg_exif_data

    @property
    def jpeg_jfif_data(self):
        """Gets the jpeg_jfif_data of this JpegProperties.

        Gets or sets the JPEG JFIF data.

        :return: The jpeg_jfif_data of this JpegProperties.
        :rtype: JfifData
        """
        return self._jpeg_jfif_data

    @jpeg_jfif_data.setter
    def jpeg_jfif_data(self, jpeg_jfif_data):
        """Sets the jpeg_jfif_data of this JpegProperties.

        Gets or sets the JPEG JFIF data.

        :param jpeg_jfif_data: The jpeg_jfif_data of this JpegProperties.
        :type: JfifData
        """
        self._jpeg_jfif_data = jpeg_jfif_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JpegProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="sharpen_filter_properties.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six

from asposeimagingcloud.models.convolution_filter_properties import ConvolutionFilterProperties


class SharpenFilterProperties(ConvolutionFilterProperties):
    """The Sharpen filter options             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'size': 'int',
        'sigma': 'float'
    }

    attribute_map = {
        'size': 'Size',
        'sigma': 'Sigma'
    }

    def __init__(self, size=None, sigma=None):
        """SharpenFilterProperties - a model defined in Swagger"""
        super(SharpenFilterProperties, self).__init__()

        self._size = None
        self._sigma = None

        if size is not None:
            self.size = size
        if sigma is not None:
            self.sigma = sigma

    @property
    def size(self):
        """Gets the size of this SharpenFilterProperties.

        Gets or sets the size.             

        :return: The size of this SharpenFilterProperties.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this SharpenFilterProperties.

        Gets or sets the size.             

        :param size: The size of this SharpenFilterProperties.
        :type: int
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")
        self._size = size

    @property
    def sigma(self):
        """Gets the sigma of this SharpenFilterProperties.

        Gets or sets the sigma.             

        :return: The sigma of this SharpenFilterProperties.
        :rtype: float
        """
        return self._sigma

    @sigma.setter
    def sigma(self, sigma):
        """Sets the sigma of this SharpenFilterProperties.

        Gets or sets the sigma.             

        :param sigma: The sigma of this SharpenFilterProperties.
        :type: float
        """
        if sigma is None:
            raise ValueError("Invalid value for `sigma`, must not be `None`")
        self._sigma = sigma

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SharpenFilterProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="dng_properties.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six


class DngProperties(object):
    """Represents information about image in DNG format.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dng_version': 'int',
        'description': 'str',
        'model': 'str',
        'camera_manufacturer': 'str',
        'is_foveon': 'int',
        'software': 'str',
        'raw_count': 'int',
        'filters': 'int',
        'colors_count': 'int',
        'xmp_data': 'str',
        'translation_cfa_dng': 'list[str]'
    }

    attribute_map = {
        'dng_version': 'DngVersion',
        'description': 'Description',
        'model': 'Model',
        'camera_manufacturer': 'CameraManufacturer',
        'is_foveon': 'IsFoveon',
        'software': 'Software',
        'raw_count': 'RawCount',
        'filters': 'Filters',
        'colors_count': 'ColorsCount',
        'xmp_data': 'XmpData',
        'translation_cfa_dng': 'TranslationCfaDng'
    }

    def __init__(self, dng_version=None, description=None, model=None, camera_manufacturer=None, is_foveon=None, software=None, raw_count=None, filters=None, colors_count=None, xmp_data=None, translation_cfa_dng=None):
        """DngProperties - a model defined in Swagger"""
        super(DngProperties, self).__init__()

        self._dng_version = None
        self._description = None
        self._model = None
        self._camera_manufacturer = None
        self._is_foveon = None
        self._software = None
        self._raw_count = None
        self._filters = None
        self._colors_count = None
        self._xmp_data = None
        self._translation_cfa_dng = None

        if dng_version is not None:
            self.dng_version = dng_version
        if description is not None:
            self.description = description
        if model is not None:
            self.model = model
        if camera_manufacturer is not None:
            self.camera_manufacturer = camera_manufacturer
        if is_foveon is not None:
            self.is_foveon = is_foveon
        if software is not None:
            self.software = software
        if raw_count is not None:
            self.raw_count = raw_count
        if filters is not None:
            self.filters = filters
        if colors_count is not None:
            self.colors_count = colors_count
        if xmp_data is not None:
            self.xmp_data = xmp_data
        if translation_cfa_dng is not None:
            self.translation_cfa_dng = translation_cfa_dng

    @property
    def dng_version(self):
        """Gets the dng_version of this DngProperties.

        Gets or sets the DNG version.

        :return: The dng_version of this DngProperties.
        :rtype: int
        """
        return self._dng_version

    @dng_version.setter
    def dng_version(self, dng_version):
        """Sets the dng_version of this DngProperties.

        Gets or sets the DNG version.

        :param dng_version: The dng_version of this DngProperties.
        :type: int
        """
        if dng_version is None:
            raise ValueError("Invalid value for `dng_version`, must not be `None`")
        self._dng_version = dng_version

    @property
    def description(self):
        """Gets the description of this DngProperties.

        Gets or sets the description of colors (RGBG, RGBE, GMCY or GBTG).

        :return: The description of this DngProperties.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DngProperties.

        Gets or sets the description of colors (RGBG, RGBE, GMCY or GBTG).

        :param description: The description of this DngProperties.
        :type: str
        """
        self._description = description

    @property
    def model(self):
        """Gets the model of this DngProperties.

        Gets or sets the camera model.

        :return: The model of this DngProperties.
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this DngProperties.

        Gets or sets the camera model.

        :param model: The model of this DngProperties.
        :type: str
        """
        self._model = model

    @property
    def camera_manufacturer(self):
        """Gets the camera_manufacturer of this DngProperties.

        Gets or sets the camera manufacturer.

        :return: The camera_manufacturer of this DngProperties.
        :rtype: str
        """
        return self._camera_manufacturer

    @camera_manufacturer.setter
    def camera_manufacturer(self, camera_manufacturer):
        """Sets the camera_manufacturer of this DngProperties.

        Gets or sets the camera manufacturer.

        :param camera_manufacturer: The camera_manufacturer of this DngProperties.
        :type: str
        """
        self._camera_manufacturer = camera_manufacturer

    @property
    def is_foveon(self):
        """Gets the is_foveon of this DngProperties.

        Gets or sets the value indicating whether it's a Foveon matrix.

        :return: The is_foveon of this DngProperties.
        :rtype: int
        """
        return self._is_foveon

    @is_foveon.setter
    def is_foveon(self, is_foveon):
        """Sets the is_foveon of this DngProperties.

        Gets or sets the value indicating whether it's a Foveon matrix.

        :param is_foveon: The is_foveon of this DngProperties.
        :type: int
        """
        if is_foveon is None:
            raise ValueError("Invalid value for `is_foveon`, must not be `None`")
        self._is_foveon = is_foveon

    @property
    def software(self):
        """Gets the software of this DngProperties.

        Gets or sets the software.

        :return: The software of this DngProperties.
        :rtype: str
        """
        return self._software

    @software.setter
    def software(self, software):
        """Sets the software of this DngProperties.

        Gets or sets the software.

        :param software: The software of this DngProperties.
        :type: str
        """
        self._software = software

    @property
    def raw_count(self):
        """Gets the raw_count of this DngProperties.

        Gets or sets the number of RAW images in file (0 means that the file has not been recognized).

        :return: The raw_count of this DngProperties.
        :rtype: int
        """
        return self._raw_count

    @raw_count.setter
    def raw_count(self, raw_count):
        """Sets the raw_count of this DngProperties.

        Gets or sets the number of RAW images in file (0 means that the file has not been recognized).

        :param raw_count: The raw_count of this DngProperties.
        :type: int
        """
        if raw_count is None:
            raise ValueError("Invalid value for `raw_count`, must not be `None`")
        self._raw_count = raw_count

    @property
    def filters(self):
        """Gets the filters of this DngProperties.

        Gets or sets the bit mask describing the order of color pixels in the matrix.

        :return: The filters of this DngProperties.
        :rtype: int
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this DngProperties.

        Gets or sets the bit mask describing the order of color pixels in the matrix.

        :param filters: The filters of this DngProperties.
        :type: int
        """
        if filters is None:
            raise ValueError("Invalid value for `filters`, must not be `None`")
        self._filters = filters

    @property
    def colors_count(self):
        """Gets the colors_count of this DngProperties.

        Gets or sets the colors count.

        :return: The colors_count of this DngProperties.
        :rtype: int
        """
        return self._colors_count

    @colors_count.setter
    def colors_count(self, colors_count):
        """Sets the colors_count of this DngProperties.

        Gets or sets the colors count.

        :param colors_count: The colors_count of this DngProperties.
        :type: int
        """
        if colors_count is None:
            raise ValueError("Invalid value for `colors_count`, must not be `None`")
        self._colors_count = colors_count

    @property
    def xmp_data(self):
        """Gets the xmp_data of this DngProperties.

        Gets or sets the XMP data.

        :return: The xmp_data of this DngProperties.
        :rtype: str
        """
        return self._xmp_data

    @xmp_data.setter
    def xmp_data(self, xmp_data):
        """Sets the xmp_data of this DngProperties.

        Gets or sets the XMP data.

        :param xmp_data: The xmp_data of this DngProperties.
        :type: str
        """
        self._xmp_data = xmp_data

    @property
    def translation_cfa_dng(self):
        """Gets the translation_cfa_dng of this DngProperties.

        Gets or sets the translation array for CFA mosaic of DNG format.

        :return: The translation_cfa_dng of this DngProperties.
        :rtype: list[str]
        """
        return self._translation_cfa_dng

    @translation_cfa_dng.setter
    def translation_cfa_dng(self, translation_cfa_dng):
        """Sets the translation_cfa_dng of this DngProperties.

        Gets or sets the translation array for CFA mosaic of DNG format.

        :param translation_cfa_dng: The translation_cfa_dng of this DngProperties.
        :type: list[str]
        """
        self._translation_cfa_dng = translation_cfa_dng

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DngProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="create_deskewed_image_request.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from asposeimagingcloud.models.requests.imaging_request import ImagingRequest
from asposeimagingcloud.models.requests.http_request import HttpRequest


class CreateDeskewedImageRequest(ImagingRequest):
    """
    Request model for create_deskewed_image operation.
    Initializes a new instance.

    :param image_data Input image
    :param resize_proportionally Resize proportionally
    :param bk_color Background color
    :param out_path Path to updated file (if this is empty, response contains streamed image)
    :param storage Your Aspose Cloud Storage name.
    """

    def __init__(self, image_data, resize_proportionally, bk_color=None, out_path=None, storage=None):
        ImagingRequest.__init__(self)
        self.image_data = image_data
        self.resize_proportionally = resize_proportionally
        self.bk_color = bk_color
        self.out_path = out_path
        self.storage = storage

    def to_http_info(self, config):
        """
        Prepares initial info for HTTP request

        :param config: Imaging API configuration
        :type: asposeimagingcloud.Configuration
        :return: http_request configured http request
        :rtype: Configuration.models.requests.HttpRequest
        """
        # verify the required parameter 'image_data' is set
        if self.image_data is None:
            raise ValueError("Missing the required parameter `image_data` when calling `create_deskewed_image`")
        # verify the required parameter 'resize_proportionally' is set
        if self.resize_proportionally is None:
            raise ValueError("Missing the required parameter `resize_proportionally` when calling `create_deskewed_image`")

        collection_formats = {}
        path = '/imaging/deskew'
        path_params = {}

        query_params = []
        if self._lowercase_first_letter('resizeProportionally') in path:
            path = path.replace('{' + self._lowercase_first_letter('resizeProportionally' + '}'), self.resize_proportionally if self.resize_proportionally is not None else '')
        else:
            if self.resize_proportionally is not None:
                query_params.append((self._lowercase_first_letter('resizeProportionally'), self.resize_proportionally))
        if self._lowercase_first_letter('bkColor') in path:
            path = path.replace('{' + self._lowercase_first_letter('bkColor' + '}'), self.bk_color if self.bk_color is not None else '')
        else:
            if self.bk_color is not None:
                query_params.append((self._lowercase_first_letter('bkColor'), self.bk_color))
        if self._lowercase_first_letter('outPath') in path:
            path = path.replace('{' + self._lowercase_first_letter('outPath' + '}'), self.out_path if self.out_path is not None else '')
        else:
            if self.out_path is not None:
                query_params.append((self._lowercase_first_letter('outPath'), self.out_path))
        if self._lowercase_first_letter('storage') in path:
            path = path.replace('{' + self._lowercase_first_letter('storage' + '}'), self.storage if self.storage is not None else '')
        else:
            if self.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), self.storage))

        header_params = {}

        form_params = []
        local_var_files = []
        if self.image_data is not None:
            local_var_files.append((self._lowercase_first_letter('imageData'), self.image_data))

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'multipart/form-data' if form_params else self._select_header_content_type(
            ['multipart/form-data'])

        # Authentication setting
        auth_settings = ['JWT']

        return HttpRequest(path, path_params, query_params, header_params, form_params, body_params, local_var_files,
                           collection_formats, auth_settings)



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="tiff_options.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six


class TiffOptions(object):
    """Represents options for TIFF frame.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_valid': 'bool',
        'artist': 'str',
        'byte_order': 'str',
        'bits_per_sample': 'list[int]',
        'compression': 'str',
        'copyright': 'str',
        'color_map': 'list[int]',
        'date_time': 'str',
        'document_name': 'str',
        'alpha_storage': 'str',
        'fill_order': 'str',
        'half_tone_hints': 'list[int]',
        'image_description': 'str',
        'ink_names': 'str',
        'scanner_manufacturer': 'str',
        'max_sample_value': 'list[int]',
        'min_sample_value': 'list[int]',
        'scanner_model': 'str',
        'page_name': 'str',
        'orientation': 'str',
        'page_number': 'list[int]',
        'photometric': 'str',
        'planar_configuration': 'str',
        'resolution_unit': 'str',
        'rows_per_strip': 'int',
        'sample_format': 'list[str]',
        'samples_per_pixel': 'int',
        'smax_sample_value': 'list[int]',
        'smin_sample_value': 'list[int]',
        'software_type': 'str',
        'strip_byte_counts': 'list[int]',
        'strip_offsets': 'list[int]',
        'sub_file_type': 'str',
        'target_printer': 'str',
        'threshholding': 'str',
        'total_pages': 'int',
        'xposition': 'float',
        'xresolution': 'float',
        'yposition': 'float',
        'yresolution': 'float',
        'fax_t4_options': 'str',
        'predictor': 'str',
        'image_length': 'int',
        'image_width': 'int',
        'valid_tag_count': 'int',
        'bits_per_pixel': 'int'
    }

    attribute_map = {
        'is_valid': 'IsValid',
        'artist': 'Artist',
        'byte_order': 'ByteOrder',
        'bits_per_sample': 'BitsPerSample',
        'compression': 'Compression',
        'copyright': 'Copyright',
        'color_map': 'ColorMap',
        'date_time': 'DateTime',
        'document_name': 'DocumentName',
        'alpha_storage': 'AlphaStorage',
        'fill_order': 'FillOrder',
        'half_tone_hints': 'HalfToneHints',
        'image_description': 'ImageDescription',
        'ink_names': 'InkNames',
        'scanner_manufacturer': 'ScannerManufacturer',
        'max_sample_value': 'MaxSampleValue',
        'min_sample_value': 'MinSampleValue',
        'scanner_model': 'ScannerModel',
        'page_name': 'PageName',
        'orientation': 'Orientation',
        'page_number': 'PageNumber',
        'photometric': 'Photometric',
        'planar_configuration': 'PlanarConfiguration',
        'resolution_unit': 'ResolutionUnit',
        'rows_per_strip': 'RowsPerStrip',
        'sample_format': 'SampleFormat',
        'samples_per_pixel': 'SamplesPerPixel',
        'smax_sample_value': 'SmaxSampleValue',
        'smin_sample_value': 'SminSampleValue',
        'software_type': 'SoftwareType',
        'strip_byte_counts': 'StripByteCounts',
        'strip_offsets': 'StripOffsets',
        'sub_file_type': 'SubFileType',
        'target_printer': 'TargetPrinter',
        'threshholding': 'Threshholding',
        'total_pages': 'TotalPages',
        'xposition': 'Xposition',
        'xresolution': 'Xresolution',
        'yposition': 'Yposition',
        'yresolution': 'Yresolution',
        'fax_t4_options': 'FaxT4Options',
        'predictor': 'Predictor',
        'image_length': 'ImageLength',
        'image_width': 'ImageWidth',
        'valid_tag_count': 'ValidTagCount',
        'bits_per_pixel': 'BitsPerPixel'
    }

    def __init__(self, is_valid=None, artist=None, byte_order=None, bits_per_sample=None, compression=None, copyright=None, color_map=None, date_time=None, document_name=None, alpha_storage=None, fill_order=None, half_tone_hints=None, image_description=None, ink_names=None, scanner_manufacturer=None, max_sample_value=None, min_sample_value=None, scanner_model=None, page_name=None, orientation=None, page_number=None, photometric=None, planar_configuration=None, resolution_unit=None, rows_per_strip=None, sample_format=None, samples_per_pixel=None, smax_sample_value=None, smin_sample_value=None, software_type=None, strip_byte_counts=None, strip_offsets=None, sub_file_type=None, target_printer=None, threshholding=None, total_pages=None, xposition=None, xresolution=None, yposition=None, yresolution=None, fax_t4_options=None, predictor=None, image_length=None, image_width=None, valid_tag_count=None, bits_per_pixel=None):
        """TiffOptions - a model defined in Swagger"""
        super(TiffOptions, self).__init__()

        self._is_valid = None
        self._artist = None
        self._byte_order = None
        self._bits_per_sample = None
        self._compression = None
        self._copyright = None
        self._color_map = None
        self._date_time = None
        self._document_name = None
        self._alpha_storage = None
        self._fill_order = None
        self._half_tone_hints = None
        self._image_description = None
        self._ink_names = None
        self._scanner_manufacturer = None
        self._max_sample_value = None
        self._min_sample_value = None
        self._scanner_model = None
        self._page_name = None
        self._orientation = None
        self._page_number = None
        self._photometric = None
        self._planar_configuration = None
        self._resolution_unit = None
        self._rows_per_strip = None
        self._sample_format = None
        self._samples_per_pixel = None
        self._smax_sample_value = None
        self._smin_sample_value = None
        self._software_type = None
        self._strip_byte_counts = None
        self._strip_offsets = None
        self._sub_file_type = None
        self._target_printer = None
        self._threshholding = None
        self._total_pages = None
        self._xposition = None
        self._xresolution = None
        self._yposition = None
        self._yresolution = None
        self._fax_t4_options = None
        self._predictor = None
        self._image_length = None
        self._image_width = None
        self._valid_tag_count = None
        self._bits_per_pixel = None

        if is_valid is not None:
            self.is_valid = is_valid
        if artist is not None:
            self.artist = artist
        if byte_order is not None:
            self.byte_order = byte_order
        if bits_per_sample is not None:
            self.bits_per_sample = bits_per_sample
        if compression is not None:
            self.compression = compression
        if copyright is not None:
            self.copyright = copyright
        if color_map is not None:
            self.color_map = color_map
        if date_time is not None:
            self.date_time = date_time
        if document_name is not None:
            self.document_name = document_name
        if alpha_storage is not None:
            self.alpha_storage = alpha_storage
        if fill_order is not None:
            self.fill_order = fill_order
        if half_tone_hints is not None:
            self.half_tone_hints = half_tone_hints
        if image_description is not None:
            self.image_description = image_description
        if ink_names is not None:
            self.ink_names = ink_names
        if scanner_manufacturer is not None:
            self.scanner_manufacturer = scanner_manufacturer
        if max_sample_value is not None:
            self.max_sample_value = max_sample_value
        if min_sample_value is not None:
            self.min_sample_value = min_sample_value
        if scanner_model is not None:
            self.scanner_model = scanner_model
        if page_name is not None:
            self.page_name = page_name
        if orientation is not None:
            self.orientation = orientation
        if page_number is not None:
            self.page_number = page_number
        if photometric is not None:
            self.photometric = photometric
        if planar_configuration is not None:
            self.planar_configuration = planar_configuration
        if resolution_unit is not None:
            self.resolution_unit = resolution_unit
        if rows_per_strip is not None:
            self.rows_per_strip = rows_per_strip
        if sample_format is not None:
            self.sample_format = sample_format
        if samples_per_pixel is not None:
            self.samples_per_pixel = samples_per_pixel
        if smax_sample_value is not None:
            self.smax_sample_value = smax_sample_value
        if smin_sample_value is not None:
            self.smin_sample_value = smin_sample_value
        if software_type is not None:
            self.software_type = software_type
        if strip_byte_counts is not None:
            self.strip_byte_counts = strip_byte_counts
        if strip_offsets is not None:
            self.strip_offsets = strip_offsets
        if sub_file_type is not None:
            self.sub_file_type = sub_file_type
        if target_printer is not None:
            self.target_printer = target_printer
        if threshholding is not None:
            self.threshholding = threshholding
        if total_pages is not None:
            self.total_pages = total_pages
        if xposition is not None:
            self.xposition = xposition
        if xresolution is not None:
            self.xresolution = xresolution
        if yposition is not None:
            self.yposition = yposition
        if yresolution is not None:
            self.yresolution = yresolution
        if fax_t4_options is not None:
            self.fax_t4_options = fax_t4_options
        if predictor is not None:
            self.predictor = predictor
        if image_length is not None:
            self.image_length = image_length
        if image_width is not None:
            self.image_width = image_width
        if valid_tag_count is not None:
            self.valid_tag_count = valid_tag_count
        if bits_per_pixel is not None:
            self.bits_per_pixel = bits_per_pixel

    @property
    def is_valid(self):
        """Gets the is_valid of this TiffOptions.

        Gets or sets a value indicating whether TIFF image has valid data.

        :return: The is_valid of this TiffOptions.
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this TiffOptions.

        Gets or sets a value indicating whether TIFF image has valid data.

        :param is_valid: The is_valid of this TiffOptions.
        :type: bool
        """
        if is_valid is None:
            raise ValueError("Invalid value for `is_valid`, must not be `None`")
        self._is_valid = is_valid

    @property
    def artist(self):
        """Gets the artist of this TiffOptions.

        Gets or sets the artist.

        :return: The artist of this TiffOptions.
        :rtype: str
        """
        return self._artist

    @artist.setter
    def artist(self, artist):
        """Sets the artist of this TiffOptions.

        Gets or sets the artist.

        :param artist: The artist of this TiffOptions.
        :type: str
        """
        self._artist = artist

    @property
    def byte_order(self):
        """Gets the byte_order of this TiffOptions.

        Gets or sets the byte order.

        :return: The byte_order of this TiffOptions.
        :rtype: str
        """
        return self._byte_order

    @byte_order.setter
    def byte_order(self, byte_order):
        """Sets the byte_order of this TiffOptions.

        Gets or sets the byte order.

        :param byte_order: The byte_order of this TiffOptions.
        :type: str
        """
        self._byte_order = byte_order

    @property
    def bits_per_sample(self):
        """Gets the bits_per_sample of this TiffOptions.

        Gets or sets the bits per sample.

        :return: The bits_per_sample of this TiffOptions.
        :rtype: list[int]
        """
        return self._bits_per_sample

    @bits_per_sample.setter
    def bits_per_sample(self, bits_per_sample):
        """Sets the bits_per_sample of this TiffOptions.

        Gets or sets the bits per sample.

        :param bits_per_sample: The bits_per_sample of this TiffOptions.
        :type: list[int]
        """
        self._bits_per_sample = bits_per_sample

    @property
    def compression(self):
        """Gets the compression of this TiffOptions.

        Gets or sets the compression.

        :return: The compression of this TiffOptions.
        :rtype: str
        """
        return self._compression

    @compression.setter
    def compression(self, compression):
        """Sets the compression of this TiffOptions.

        Gets or sets the compression.

        :param compression: The compression of this TiffOptions.
        :type: str
        """
        self._compression = compression

    @property
    def copyright(self):
        """Gets the copyright of this TiffOptions.

        Gets or sets the copyright info.

        :return: The copyright of this TiffOptions.
        :rtype: str
        """
        return self._copyright

    @copyright.setter
    def copyright(self, copyright):
        """Sets the copyright of this TiffOptions.

        Gets or sets the copyright info.

        :param copyright: The copyright of this TiffOptions.
        :type: str
        """
        self._copyright = copyright

    @property
    def color_map(self):
        """Gets the color_map of this TiffOptions.

        Gets or sets the color map.

        :return: The color_map of this TiffOptions.
        :rtype: list[int]
        """
        return self._color_map

    @color_map.setter
    def color_map(self, color_map):
        """Sets the color_map of this TiffOptions.

        Gets or sets the color map.

        :param color_map: The color_map of this TiffOptions.
        :type: list[int]
        """
        self._color_map = color_map

    @property
    def date_time(self):
        """Gets the date_time of this TiffOptions.

        Gets or sets the date and time.

        :return: The date_time of this TiffOptions.
        :rtype: str
        """
        return self._date_time

    @date_time.setter
    def date_time(self, date_time):
        """Sets the date_time of this TiffOptions.

        Gets or sets the date and time.

        :param date_time: The date_time of this TiffOptions.
        :type: str
        """
        self._date_time = date_time

    @property
    def document_name(self):
        """Gets the document_name of this TiffOptions.

        Gets or sets the document name.

        :return: The document_name of this TiffOptions.
        :rtype: str
        """
        return self._document_name

    @document_name.setter
    def document_name(self, document_name):
        """Sets the document_name of this TiffOptions.

        Gets or sets the document name.

        :param document_name: The document_name of this TiffOptions.
        :type: str
        """
        self._document_name = document_name

    @property
    def alpha_storage(self):
        """Gets the alpha_storage of this TiffOptions.

        Gets or sets the alpha storage.

        :return: The alpha_storage of this TiffOptions.
        :rtype: str
        """
        return self._alpha_storage

    @alpha_storage.setter
    def alpha_storage(self, alpha_storage):
        """Sets the alpha_storage of this TiffOptions.

        Gets or sets the alpha storage.

        :param alpha_storage: The alpha_storage of this TiffOptions.
        :type: str
        """
        self._alpha_storage = alpha_storage

    @property
    def fill_order(self):
        """Gets the fill_order of this TiffOptions.

        Gets or sets the fill order.

        :return: The fill_order of this TiffOptions.
        :rtype: str
        """
        return self._fill_order

    @fill_order.setter
    def fill_order(self, fill_order):
        """Sets the fill_order of this TiffOptions.

        Gets or sets the fill order.

        :param fill_order: The fill_order of this TiffOptions.
        :type: str
        """
        self._fill_order = fill_order

    @property
    def half_tone_hints(self):
        """Gets the half_tone_hints of this TiffOptions.

        Gets or sets the half-tone hints.

        :return: The half_tone_hints of this TiffOptions.
        :rtype: list[int]
        """
        return self._half_tone_hints

    @half_tone_hints.setter
    def half_tone_hints(self, half_tone_hints):
        """Sets the half_tone_hints of this TiffOptions.

        Gets or sets the half-tone hints.

        :param half_tone_hints: The half_tone_hints of this TiffOptions.
        :type: list[int]
        """
        self._half_tone_hints = half_tone_hints

    @property
    def image_description(self):
        """Gets the image_description of this TiffOptions.

        Gets or sets the image description.

        :return: The image_description of this TiffOptions.
        :rtype: str
        """
        return self._image_description

    @image_description.setter
    def image_description(self, image_description):
        """Sets the image_description of this TiffOptions.

        Gets or sets the image description.

        :param image_description: The image_description of this TiffOptions.
        :type: str
        """
        self._image_description = image_description

    @property
    def ink_names(self):
        """Gets the ink_names of this TiffOptions.

        Gets or sets the ink names.

        :return: The ink_names of this TiffOptions.
        :rtype: str
        """
        return self._ink_names

    @ink_names.setter
    def ink_names(self, ink_names):
        """Sets the ink_names of this TiffOptions.

        Gets or sets the ink names.

        :param ink_names: The ink_names of this TiffOptions.
        :type: str
        """
        self._ink_names = ink_names

    @property
    def scanner_manufacturer(self):
        """Gets the scanner_manufacturer of this TiffOptions.

        Gets or sets the scanner manufacturer.

        :return: The scanner_manufacturer of this TiffOptions.
        :rtype: str
        """
        return self._scanner_manufacturer

    @scanner_manufacturer.setter
    def scanner_manufacturer(self, scanner_manufacturer):
        """Sets the scanner_manufacturer of this TiffOptions.

        Gets or sets the scanner manufacturer.

        :param scanner_manufacturer: The scanner_manufacturer of this TiffOptions.
        :type: str
        """
        self._scanner_manufacturer = scanner_manufacturer

    @property
    def max_sample_value(self):
        """Gets the max_sample_value of this TiffOptions.

        Gets or sets the max sample value.

        :return: The max_sample_value of this TiffOptions.
        :rtype: list[int]
        """
        return self._max_sample_value

    @max_sample_value.setter
    def max_sample_value(self, max_sample_value):
        """Sets the max_sample_value of this TiffOptions.

        Gets or sets the max sample value.

        :param max_sample_value: The max_sample_value of this TiffOptions.
        :type: list[int]
        """
        self._max_sample_value = max_sample_value

    @property
    def min_sample_value(self):
        """Gets the min_sample_value of this TiffOptions.

        Gets or sets the min sample value.

        :return: The min_sample_value of this TiffOptions.
        :rtype: list[int]
        """
        return self._min_sample_value

    @min_sample_value.setter
    def min_sample_value(self, min_sample_value):
        """Sets the min_sample_value of this TiffOptions.

        Gets or sets the min sample value.

        :param min_sample_value: The min_sample_value of this TiffOptions.
        :type: list[int]
        """
        self._min_sample_value = min_sample_value

    @property
    def scanner_model(self):
        """Gets the scanner_model of this TiffOptions.

        Gets or sets the scanner model.

        :return: The scanner_model of this TiffOptions.
        :rtype: str
        """
        return self._scanner_model

    @scanner_model.setter
    def scanner_model(self, scanner_model):
        """Sets the scanner_model of this TiffOptions.

        Gets or sets the scanner model.

        :param scanner_model: The scanner_model of this TiffOptions.
        :type: str
        """
        self._scanner_model = scanner_model

    @property
    def page_name(self):
        """Gets the page_name of this TiffOptions.

        Gets or sets the page name.

        :return: The page_name of this TiffOptions.
        :rtype: str
        """
        return self._page_name

    @page_name.setter
    def page_name(self, page_name):
        """Sets the page_name of this TiffOptions.

        Gets or sets the page name.

        :param page_name: The page_name of this TiffOptions.
        :type: str
        """
        self._page_name = page_name

    @property
    def orientation(self):
        """Gets the orientation of this TiffOptions.

        Gets or sets the orientation.

        :return: The orientation of this TiffOptions.
        :rtype: str
        """
        return self._orientation

    @orientation.setter
    def orientation(self, orientation):
        """Sets the orientation of this TiffOptions.

        Gets or sets the orientation.

        :param orientation: The orientation of this TiffOptions.
        :type: str
        """
        self._orientation = orientation

    @property
    def page_number(self):
        """Gets the page_number of this TiffOptions.

        Gets or sets the page number.

        :return: The page_number of this TiffOptions.
        :rtype: list[int]
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this TiffOptions.

        Gets or sets the page number.

        :param page_number: The page_number of this TiffOptions.
        :type: list[int]
        """
        self._page_number = page_number

    @property
    def photometric(self):
        """Gets the photometric of this TiffOptions.

        Gets or sets the photometric interpretation.

        :return: The photometric of this TiffOptions.
        :rtype: str
        """
        return self._photometric

    @photometric.setter
    def photometric(self, photometric):
        """Sets the photometric of this TiffOptions.

        Gets or sets the photometric interpretation.

        :param photometric: The photometric of this TiffOptions.
        :type: str
        """
        self._photometric = photometric

    @property
    def planar_configuration(self):
        """Gets the planar_configuration of this TiffOptions.

        Gets or sets the planar configuration.

        :return: The planar_configuration of this TiffOptions.
        :rtype: str
        """
        return self._planar_configuration

    @planar_configuration.setter
    def planar_configuration(self, planar_configuration):
        """Sets the planar_configuration of this TiffOptions.

        Gets or sets the planar configuration.

        :param planar_configuration: The planar_configuration of this TiffOptions.
        :type: str
        """
        self._planar_configuration = planar_configuration

    @property
    def resolution_unit(self):
        """Gets the resolution_unit of this TiffOptions.

        Gets or sets the resolution unit.

        :return: The resolution_unit of this TiffOptions.
        :rtype: str
        """
        return self._resolution_unit

    @resolution_unit.setter
    def resolution_unit(self, resolution_unit):
        """Sets the resolution_unit of this TiffOptions.

        Gets or sets the resolution unit.

        :param resolution_unit: The resolution_unit of this TiffOptions.
        :type: str
        """
        self._resolution_unit = resolution_unit

    @property
    def rows_per_strip(self):
        """Gets the rows_per_strip of this TiffOptions.

        Gets or sets the rows per strip.

        :return: The rows_per_strip of this TiffOptions.
        :rtype: int
        """
        return self._rows_per_strip

    @rows_per_strip.setter
    def rows_per_strip(self, rows_per_strip):
        """Sets the rows_per_strip of this TiffOptions.

        Gets or sets the rows per strip.

        :param rows_per_strip: The rows_per_strip of this TiffOptions.
        :type: int
        """
        if rows_per_strip is None:
            raise ValueError("Invalid value for `rows_per_strip`, must not be `None`")
        self._rows_per_strip = rows_per_strip

    @property
    def sample_format(self):
        """Gets the sample_format of this TiffOptions.

        Gets or sets the sample format.

        :return: The sample_format of this TiffOptions.
        :rtype: list[str]
        """
        return self._sample_format

    @sample_format.setter
    def sample_format(self, sample_format):
        """Sets the sample_format of this TiffOptions.

        Gets or sets the sample format.

        :param sample_format: The sample_format of this TiffOptions.
        :type: list[str]
        """
        self._sample_format = sample_format

    @property
    def samples_per_pixel(self):
        """Gets the samples_per_pixel of this TiffOptions.

        Gets or sets the samples per pixel.

        :return: The samples_per_pixel of this TiffOptions.
        :rtype: int
        """
        return self._samples_per_pixel

    @samples_per_pixel.setter
    def samples_per_pixel(self, samples_per_pixel):
        """Sets the samples_per_pixel of this TiffOptions.

        Gets or sets the samples per pixel.

        :param samples_per_pixel: The samples_per_pixel of this TiffOptions.
        :type: int
        """
        if samples_per_pixel is None:
            raise ValueError("Invalid value for `samples_per_pixel`, must not be `None`")
        self._samples_per_pixel = samples_per_pixel

    @property
    def smax_sample_value(self):
        """Gets the smax_sample_value of this TiffOptions.

        Gets or sets the Smax sample value.

        :return: The smax_sample_value of this TiffOptions.
        :rtype: list[int]
        """
        return self._smax_sample_value

    @smax_sample_value.setter
    def smax_sample_value(self, smax_sample_value):
        """Sets the smax_sample_value of this TiffOptions.

        Gets or sets the Smax sample value.

        :param smax_sample_value: The smax_sample_value of this TiffOptions.
        :type: list[int]
        """
        self._smax_sample_value = smax_sample_value

    @property
    def smin_sample_value(self):
        """Gets the smin_sample_value of this TiffOptions.

        Gets or sets the Smin sample value.

        :return: The smin_sample_value of this TiffOptions.
        :rtype: list[int]
        """
        return self._smin_sample_value

    @smin_sample_value.setter
    def smin_sample_value(self, smin_sample_value):
        """Sets the smin_sample_value of this TiffOptions.

        Gets or sets the Smin sample value.

        :param smin_sample_value: The smin_sample_value of this TiffOptions.
        :type: list[int]
        """
        self._smin_sample_value = smin_sample_value

    @property
    def software_type(self):
        """Gets the software_type of this TiffOptions.

        Gets or sets the software type.

        :return: The software_type of this TiffOptions.
        :rtype: str
        """
        return self._software_type

    @software_type.setter
    def software_type(self, software_type):
        """Sets the software_type of this TiffOptions.

        Gets or sets the software type.

        :param software_type: The software_type of this TiffOptions.
        :type: str
        """
        self._software_type = software_type

    @property
    def strip_byte_counts(self):
        """Gets the strip_byte_counts of this TiffOptions.

        Gets or sets the strip byte counts.

        :return: The strip_byte_counts of this TiffOptions.
        :rtype: list[int]
        """
        return self._strip_byte_counts

    @strip_byte_counts.setter
    def strip_byte_counts(self, strip_byte_counts):
        """Sets the strip_byte_counts of this TiffOptions.

        Gets or sets the strip byte counts.

        :param strip_byte_counts: The strip_byte_counts of this TiffOptions.
        :type: list[int]
        """
        self._strip_byte_counts = strip_byte_counts

    @property
    def strip_offsets(self):
        """Gets the strip_offsets of this TiffOptions.

        Gets or sets the strip offsets.

        :return: The strip_offsets of this TiffOptions.
        :rtype: list[int]
        """
        return self._strip_offsets

    @strip_offsets.setter
    def strip_offsets(self, strip_offsets):
        """Sets the strip_offsets of this TiffOptions.

        Gets or sets the strip offsets.

        :param strip_offsets: The strip_offsets of this TiffOptions.
        :type: list[int]
        """
        self._strip_offsets = strip_offsets

    @property
    def sub_file_type(self):
        """Gets the sub_file_type of this TiffOptions.

        Gets or sets the subfile type.

        :return: The sub_file_type of this TiffOptions.
        :rtype: str
        """
        return self._sub_file_type

    @sub_file_type.setter
    def sub_file_type(self, sub_file_type):
        """Sets the sub_file_type of this TiffOptions.

        Gets or sets the subfile type.

        :param sub_file_type: The sub_file_type of this TiffOptions.
        :type: str
        """
        self._sub_file_type = sub_file_type

    @property
    def target_printer(self):
        """Gets the target_printer of this TiffOptions.

        Gets or sets the target printer.

        :return: The target_printer of this TiffOptions.
        :rtype: str
        """
        return self._target_printer

    @target_printer.setter
    def target_printer(self, target_printer):
        """Sets the target_printer of this TiffOptions.

        Gets or sets the target printer.

        :param target_printer: The target_printer of this TiffOptions.
        :type: str
        """
        self._target_printer = target_printer

    @property
    def threshholding(self):
        """Gets the threshholding of this TiffOptions.

        Gets or sets the threshholding.

        :return: The threshholding of this TiffOptions.
        :rtype: str
        """
        return self._threshholding

    @threshholding.setter
    def threshholding(self, threshholding):
        """Sets the threshholding of this TiffOptions.

        Gets or sets the threshholding.

        :param threshholding: The threshholding of this TiffOptions.
        :type: str
        """
        self._threshholding = threshholding

    @property
    def total_pages(self):
        """Gets the total_pages of this TiffOptions.

        Gets or sets the total pages count.

        :return: The total_pages of this TiffOptions.
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this TiffOptions.

        Gets or sets the total pages count.

        :param total_pages: The total_pages of this TiffOptions.
        :type: int
        """
        if total_pages is None:
            raise ValueError("Invalid value for `total_pages`, must not be `None`")
        self._total_pages = total_pages

    @property
    def xposition(self):
        """Gets the xposition of this TiffOptions.

        Gets or sets the X position.

        :return: The xposition of this TiffOptions.
        :rtype: float
        """
        return self._xposition

    @xposition.setter
    def xposition(self, xposition):
        """Sets the xposition of this TiffOptions.

        Gets or sets the X position.

        :param xposition: The xposition of this TiffOptions.
        :type: float
        """
        if xposition is None:
            raise ValueError("Invalid value for `xposition`, must not be `None`")
        self._xposition = xposition

    @property
    def xresolution(self):
        """Gets the xresolution of this TiffOptions.

        Gets or sets the X resolution.

        :return: The xresolution of this TiffOptions.
        :rtype: float
        """
        return self._xresolution

    @xresolution.setter
    def xresolution(self, xresolution):
        """Sets the xresolution of this TiffOptions.

        Gets or sets the X resolution.

        :param xresolution: The xresolution of this TiffOptions.
        :type: float
        """
        if xresolution is None:
            raise ValueError("Invalid value for `xresolution`, must not be `None`")
        self._xresolution = xresolution

    @property
    def yposition(self):
        """Gets the yposition of this TiffOptions.

        Gets or sets the Y position.

        :return: The yposition of this TiffOptions.
        :rtype: float
        """
        return self._yposition

    @yposition.setter
    def yposition(self, yposition):
        """Sets the yposition of this TiffOptions.

        Gets or sets the Y position.

        :param yposition: The yposition of this TiffOptions.
        :type: float
        """
        if yposition is None:
            raise ValueError("Invalid value for `yposition`, must not be `None`")
        self._yposition = yposition

    @property
    def yresolution(self):
        """Gets the yresolution of this TiffOptions.

        Gets or sets the Y resolution.

        :return: The yresolution of this TiffOptions.
        :rtype: float
        """
        return self._yresolution

    @yresolution.setter
    def yresolution(self, yresolution):
        """Sets the yresolution of this TiffOptions.

        Gets or sets the Y resolution.

        :param yresolution: The yresolution of this TiffOptions.
        :type: float
        """
        if yresolution is None:
            raise ValueError("Invalid value for `yresolution`, must not be `None`")
        self._yresolution = yresolution

    @property
    def fax_t4_options(self):
        """Gets the fax_t4_options of this TiffOptions.

        Gets or sets the FaxT4 Options.

        :return: The fax_t4_options of this TiffOptions.
        :rtype: str
        """
        return self._fax_t4_options

    @fax_t4_options.setter
    def fax_t4_options(self, fax_t4_options):
        """Sets the fax_t4_options of this TiffOptions.

        Gets or sets the FaxT4 Options.

        :param fax_t4_options: The fax_t4_options of this TiffOptions.
        :type: str
        """
        self._fax_t4_options = fax_t4_options

    @property
    def predictor(self):
        """Gets the predictor of this TiffOptions.

        Gets or sets the predictor (a mathematical operator that is applied to the image data before an encoding scheme is applied).

        :return: The predictor of this TiffOptions.
        :rtype: str
        """
        return self._predictor

    @predictor.setter
    def predictor(self, predictor):
        """Sets the predictor of this TiffOptions.

        Gets or sets the predictor (a mathematical operator that is applied to the image data before an encoding scheme is applied).

        :param predictor: The predictor of this TiffOptions.
        :type: str
        """
        self._predictor = predictor

    @property
    def image_length(self):
        """Gets the image_length of this TiffOptions.

        Gets or sets the image length.

        :return: The image_length of this TiffOptions.
        :rtype: int
        """
        return self._image_length

    @image_length.setter
    def image_length(self, image_length):
        """Sets the image_length of this TiffOptions.

        Gets or sets the image length.

        :param image_length: The image_length of this TiffOptions.
        :type: int
        """
        if image_length is None:
            raise ValueError("Invalid value for `image_length`, must not be `None`")
        self._image_length = image_length

    @property
    def image_width(self):
        """Gets the image_width of this TiffOptions.

        Gets or sets the image width.

        :return: The image_width of this TiffOptions.
        :rtype: int
        """
        return self._image_width

    @image_width.setter
    def image_width(self, image_width):
        """Sets the image_width of this TiffOptions.

        Gets or sets the image width.

        :param image_width: The image_width of this TiffOptions.
        :type: int
        """
        if image_width is None:
            raise ValueError("Invalid value for `image_width`, must not be `None`")
        self._image_width = image_width

    @property
    def valid_tag_count(self):
        """Gets the valid_tag_count of this TiffOptions.

        Gets or sets the valid tag count.

        :return: The valid_tag_count of this TiffOptions.
        :rtype: int
        """
        return self._valid_tag_count

    @valid_tag_count.setter
    def valid_tag_count(self, valid_tag_count):
        """Sets the valid_tag_count of this TiffOptions.

        Gets or sets the valid tag count.

        :param valid_tag_count: The valid_tag_count of this TiffOptions.
        :type: int
        """
        if valid_tag_count is None:
            raise ValueError("Invalid value for `valid_tag_count`, must not be `None`")
        self._valid_tag_count = valid_tag_count

    @property
    def bits_per_pixel(self):
        """Gets the bits_per_pixel of this TiffOptions.

        Gets or sets the bits per pixel.

        :return: The bits_per_pixel of this TiffOptions.
        :rtype: int
        """
        return self._bits_per_pixel

    @bits_per_pixel.setter
    def bits_per_pixel(self, bits_per_pixel):
        """Sets the bits_per_pixel of this TiffOptions.

        Gets or sets the bits per pixel.

        :param bits_per_pixel: The bits_per_pixel of this TiffOptions.
        :type: int
        """
        if bits_per_pixel is None:
            raise ValueError("Invalid value for `bits_per_pixel`, must not be `None`")
        self._bits_per_pixel = bits_per_pixel

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TiffOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="__init__.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

# import apis into sdk package
from asposeimagingcloud.api.imaging_api import ImagingApi

# import ApiClient
from asposeimagingcloud.api_client import ApiClient
from asposeimagingcloud.configuration import Configuration
# import models into sdk package
from asposeimagingcloud.models.available_labels_list import AvailableLabelsList
from asposeimagingcloud.models.bmp_properties import BmpProperties
from asposeimagingcloud.models.detected_object import DetectedObject
from asposeimagingcloud.models.detected_object_list import DetectedObjectList
from asposeimagingcloud.models.dicom_properties import DicomProperties
from asposeimagingcloud.models.disc_usage import DiscUsage
from asposeimagingcloud.models.djvu_properties import DjvuProperties
from asposeimagingcloud.models.dng_properties import DngProperties
from asposeimagingcloud.models.eps_properties import EpsProperties
from asposeimagingcloud.models.error import Error
from asposeimagingcloud.models.error_details import ErrorDetails
from asposeimagingcloud.models.exif_data import ExifData
from asposeimagingcloud.models.file_versions import FileVersions
from asposeimagingcloud.models.files_list import FilesList
from asposeimagingcloud.models.files_upload_result import FilesUploadResult
from asposeimagingcloud.models.filter_properties_base import FilterPropertiesBase
from asposeimagingcloud.models.gif_properties import GifProperties
from asposeimagingcloud.models.image_duplicates import ImageDuplicates
from asposeimagingcloud.models.image_duplicates_set import ImageDuplicatesSet
from asposeimagingcloud.models.image_features import ImageFeatures
from asposeimagingcloud.models.imaging_response import ImagingResponse
from asposeimagingcloud.models.jfif_data import JfifData
from asposeimagingcloud.models.jpeg2000_properties import Jpeg2000Properties
from asposeimagingcloud.models.jpeg_properties import JpegProperties
from asposeimagingcloud.models.object_exist import ObjectExist
from asposeimagingcloud.models.odg_metadata import OdgMetadata
from asposeimagingcloud.models.odg_page import OdgPage
from asposeimagingcloud.models.odg_properties import OdgProperties
from asposeimagingcloud.models.png_properties import PngProperties
from asposeimagingcloud.models.psd_properties import PsdProperties
from asposeimagingcloud.models.rectangle import Rectangle
from asposeimagingcloud.models.search_context_status import SearchContextStatus
from asposeimagingcloud.models.search_result import SearchResult
from asposeimagingcloud.models.search_results_set import SearchResultsSet
from asposeimagingcloud.models.storage_exist import StorageExist
from asposeimagingcloud.models.storage_file import StorageFile
from asposeimagingcloud.models.svg_properties import SvgProperties
from asposeimagingcloud.models.tiff_frame import TiffFrame
from asposeimagingcloud.models.tiff_options import TiffOptions
from asposeimagingcloud.models.tiff_properties import TiffProperties
from asposeimagingcloud.models.web_p_properties import WebPProperties
from asposeimagingcloud.models.big_rectangular_filter_properties import BigRectangularFilterProperties
from asposeimagingcloud.models.bilateral_smoothing_filter_properties import BilateralSmoothingFilterProperties
from asposeimagingcloud.models.convolution_filter_properties import ConvolutionFilterProperties
from asposeimagingcloud.models.deconvolution_filter_properties import DeconvolutionFilterProperties
from asposeimagingcloud.models.file_version import FileVersion
from asposeimagingcloud.models.jpeg_exif_data import JpegExifData
from asposeimagingcloud.models.median_filter_properties import MedianFilterProperties
from asposeimagingcloud.models.small_rectangular_filter_properties import SmallRectangularFilterProperties
from asposeimagingcloud.models.gauss_wiener_filter_properties import GaussWienerFilterProperties
from asposeimagingcloud.models.gaussian_blur_filter_properties import GaussianBlurFilterProperties
from asposeimagingcloud.models.motion_wiener_filter_properties import MotionWienerFilterProperties
from asposeimagingcloud.models.sharpen_filter_properties import SharpenFilterProperties

from asposeimagingcloud.models.requests.add_search_image_request import AddSearchImageRequest
from asposeimagingcloud.models.requests.append_tiff_request import AppendTiffRequest
from asposeimagingcloud.models.requests.compare_images_request import CompareImagesRequest
from asposeimagingcloud.models.requests.convert_image_request import ConvertImageRequest
from asposeimagingcloud.models.requests.convert_tiff_to_fax_request import ConvertTiffToFaxRequest
from asposeimagingcloud.models.requests.copy_file_request import CopyFileRequest
from asposeimagingcloud.models.requests.copy_folder_request import CopyFolderRequest
from asposeimagingcloud.models.requests.create_converted_image_request import CreateConvertedImageRequest
from asposeimagingcloud.models.requests.create_cropped_image_request import CreateCroppedImageRequest
from asposeimagingcloud.models.requests.create_deskewed_image_request import CreateDeskewedImageRequest
from asposeimagingcloud.models.requests.create_fax_tiff_request import CreateFaxTiffRequest
from asposeimagingcloud.models.requests.create_folder_request import CreateFolderRequest
from asposeimagingcloud.models.requests.create_grayscaled_image_request import CreateGrayscaledImageRequest
from asposeimagingcloud.models.requests.create_image_features_request import CreateImageFeaturesRequest
from asposeimagingcloud.models.requests.create_image_frame_range_request import CreateImageFrameRangeRequest
from asposeimagingcloud.models.requests.create_image_frame_request import CreateImageFrameRequest
from asposeimagingcloud.models.requests.create_image_search_request import CreateImageSearchRequest
from asposeimagingcloud.models.requests.create_image_tag_request import CreateImageTagRequest
from asposeimagingcloud.models.requests.create_modified_bmp_request import CreateModifiedBmpRequest
from asposeimagingcloud.models.requests.create_modified_emf_request import CreateModifiedEmfRequest
from asposeimagingcloud.models.requests.create_modified_gif_request import CreateModifiedGifRequest
from asposeimagingcloud.models.requests.create_modified_jpeg2000_request import CreateModifiedJpeg2000Request
from asposeimagingcloud.models.requests.create_modified_jpeg_request import CreateModifiedJpegRequest
from asposeimagingcloud.models.requests.create_modified_psd_request import CreateModifiedPsdRequest
from asposeimagingcloud.models.requests.create_modified_svg_request import CreateModifiedSvgRequest
from asposeimagingcloud.models.requests.create_modified_tiff_request import CreateModifiedTiffRequest
from asposeimagingcloud.models.requests.create_modified_web_p_request import CreateModifiedWebPRequest
from asposeimagingcloud.models.requests.create_modified_wmf_request import CreateModifiedWmfRequest
from asposeimagingcloud.models.requests.create_object_bounds_request import CreateObjectBoundsRequest
from asposeimagingcloud.models.requests.create_resized_image_request import CreateResizedImageRequest
from asposeimagingcloud.models.requests.create_rotate_flipped_image_request import CreateRotateFlippedImageRequest
from asposeimagingcloud.models.requests.create_updated_image_request import CreateUpdatedImageRequest
from asposeimagingcloud.models.requests.create_visual_object_bounds_request import CreateVisualObjectBoundsRequest
from asposeimagingcloud.models.requests.create_web_site_image_features_request import CreateWebSiteImageFeaturesRequest
from asposeimagingcloud.models.requests.crop_image_request import CropImageRequest
from asposeimagingcloud.models.requests.delete_file_request import DeleteFileRequest
from asposeimagingcloud.models.requests.delete_folder_request import DeleteFolderRequest
from asposeimagingcloud.models.requests.delete_image_features_request import DeleteImageFeaturesRequest
from asposeimagingcloud.models.requests.delete_image_search_request import DeleteImageSearchRequest
from asposeimagingcloud.models.requests.delete_search_image_request import DeleteSearchImageRequest
from asposeimagingcloud.models.requests.deskew_image_request import DeskewImageRequest
from asposeimagingcloud.models.requests.download_file_request import DownloadFileRequest
from asposeimagingcloud.models.requests.extract_image_features_request import ExtractImageFeaturesRequest
from asposeimagingcloud.models.requests.extract_image_frame_properties_request import ExtractImageFramePropertiesRequest
from asposeimagingcloud.models.requests.extract_image_properties_request import ExtractImagePropertiesRequest
from asposeimagingcloud.models.requests.filter_effect_image_request import FilterEffectImageRequest
from asposeimagingcloud.models.requests.find_images_by_tags_request import FindImagesByTagsRequest
from asposeimagingcloud.models.requests.find_image_duplicates_request import FindImageDuplicatesRequest
from asposeimagingcloud.models.requests.find_similar_images_request import FindSimilarImagesRequest
from asposeimagingcloud.models.requests.get_available_labels_request import GetAvailableLabelsRequest
from asposeimagingcloud.models.requests.get_disc_usage_request import GetDiscUsageRequest
from asposeimagingcloud.models.requests.get_files_list_request import GetFilesListRequest
from asposeimagingcloud.models.requests.get_file_versions_request import GetFileVersionsRequest
from asposeimagingcloud.models.requests.get_image_features_request import GetImageFeaturesRequest
from asposeimagingcloud.models.requests.get_image_frame_properties_request import GetImageFramePropertiesRequest
from asposeimagingcloud.models.requests.get_image_frame_range_request import GetImageFrameRangeRequest
from asposeimagingcloud.models.requests.get_image_frame_request import GetImageFrameRequest
from asposeimagingcloud.models.requests.get_image_properties_request import GetImagePropertiesRequest
from asposeimagingcloud.models.requests.get_image_search_status_request import GetImageSearchStatusRequest
from asposeimagingcloud.models.requests.get_object_bounds_request import GetObjectBoundsRequest
from asposeimagingcloud.models.requests.get_search_image_request import GetSearchImageRequest
from asposeimagingcloud.models.requests.get_visual_object_bounds_request import GetVisualObjectBoundsRequest
from asposeimagingcloud.models.requests.grayscale_image_request import GrayscaleImageRequest
from asposeimagingcloud.models.requests.http_request import HttpRequest
from asposeimagingcloud.models.requests.imaging_request import ImagingRequest
from asposeimagingcloud.models.requests.modify_bmp_request import ModifyBmpRequest
from asposeimagingcloud.models.requests.modify_emf_request import ModifyEmfRequest
from asposeimagingcloud.models.requests.modify_gif_request import ModifyGifRequest
from asposeimagingcloud.models.requests.modify_jpeg2000_request import ModifyJpeg2000Request
from asposeimagingcloud.models.requests.modify_jpeg_request import ModifyJpegRequest
from asposeimagingcloud.models.requests.modify_psd_request import ModifyPsdRequest
from asposeimagingcloud.models.requests.modify_svg_request import ModifySvgRequest
from asposeimagingcloud.models.requests.modify_tiff_request import ModifyTiffRequest
from asposeimagingcloud.models.requests.modify_web_p_request import ModifyWebPRequest
from asposeimagingcloud.models.requests.modify_wmf_request import ModifyWmfRequest
from asposeimagingcloud.models.requests.move_file_request import MoveFileRequest
from asposeimagingcloud.models.requests.move_folder_request import MoveFolderRequest
from asposeimagingcloud.models.requests.object_exists_request import ObjectExistsRequest
from asposeimagingcloud.models.requests.resize_image_request import ResizeImageRequest
from asposeimagingcloud.models.requests.rotate_flip_image_request import RotateFlipImageRequest
from asposeimagingcloud.models.requests.storage_exists_request import StorageExistsRequest
from asposeimagingcloud.models.requests.update_image_features_request import UpdateImageFeaturesRequest
from asposeimagingcloud.models.requests.update_image_request import UpdateImageRequest
from asposeimagingcloud.models.requests.update_search_image_request import UpdateSearchImageRequest
from asposeimagingcloud.models.requests.upload_file_request import UploadFileRequest




#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="find_images_by_tags_request.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from asposeimagingcloud.models.requests.imaging_request import ImagingRequest
from asposeimagingcloud.models.requests.http_request import HttpRequest


class FindImagesByTagsRequest(ImagingRequest):
    """
    Request model for find_images_by_tags operation.
    Initializes a new instance.

    :param tags Tags array for searching
    :param search_context_id The search context identifier.
    :param similarity_threshold The similarity threshold.
    :param max_count The maximum count.
    :param folder The folder.
    :param storage The storage.
    """

    def __init__(self, tags, search_context_id, similarity_threshold, max_count, folder=None, storage=None):
        ImagingRequest.__init__(self)
        self.tags = tags
        self.search_context_id = search_context_id
        self.similarity_threshold = similarity_threshold
        self.max_count = max_count
        self.folder = folder
        self.storage = storage

    def to_http_info(self, config):
        """
        Prepares initial info for HTTP request

        :param config: Imaging API configuration
        :type: asposeimagingcloud.Configuration
        :return: http_request configured http request
        :rtype: Configuration.models.requests.HttpRequest
        """
        # verify the required parameter 'tags' is set
        if self.tags is None:
            raise ValueError("Missing the required parameter `tags` when calling `find_images_by_tags`")
        # verify the required parameter 'search_context_id' is set
        if self.search_context_id is None:
            raise ValueError("Missing the required parameter `search_context_id` when calling `find_images_by_tags`")
        # verify the required parameter 'similarity_threshold' is set
        if self.similarity_threshold is None:
            raise ValueError("Missing the required parameter `similarity_threshold` when calling `find_images_by_tags`")
        # verify the required parameter 'max_count' is set
        if self.max_count is None:
            raise ValueError("Missing the required parameter `max_count` when calling `find_images_by_tags`")

        collection_formats = {}
        path = '/imaging/ai/imageSearch/{searchContextId}/findByTags'
        path_params = {}
        if self.search_context_id is not None:
            path_params[self._lowercase_first_letter('searchContextId')] = self.search_context_id

        query_params = []
        if self._lowercase_first_letter('similarityThreshold') in path:
            path = path.replace('{' + self._lowercase_first_letter('similarityThreshold' + '}'), self.similarity_threshold if self.similarity_threshold is not None else '')
        else:
            if self.similarity_threshold is not None:
                query_params.append((self._lowercase_first_letter('similarityThreshold'), self.similarity_threshold))
        if self._lowercase_first_letter('maxCount') in path:
            path = path.replace('{' + self._lowercase_first_letter('maxCount' + '}'), self.max_count if self.max_count is not None else '')
        else:
            if self.max_count is not None:
                query_params.append((self._lowercase_first_letter('maxCount'), self.max_count))
        if self._lowercase_first_letter('folder') in path:
            path = path.replace('{' + self._lowercase_first_letter('folder' + '}'), self.folder if self.folder is not None else '')
        else:
            if self.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), self.folder))
        if self._lowercase_first_letter('storage') in path:
            path = path.replace('{' + self._lowercase_first_letter('storage' + '}'), self.storage if self.storage is not None else '')
        else:
            if self.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), self.storage))

        header_params = {}

        form_params = []
        local_var_files = []
        if self.tags is not None:
            form_params.append((self._lowercase_first_letter('tags'), self.tags))

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = 'multipart/form-data' if form_params else self._select_header_content_type(
            ['application/json', 'multipart/form-data'])

        # Authentication setting
        auth_settings = ['JWT']

        return HttpRequest(path, path_params, query_params, header_params, form_params, body_params, local_var_files,
                           collection_formats, auth_settings)



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="setup.py">
#    Copyright (c) 2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from setuptools import setup, find_packages

NAME = "aspose-imaging-cloud"
VERSION = "20.9.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "urllib3>=1.22",
    "six>=1.11",
    "certifi>=2018.1",
    "python_dateutil>=2.8"
]

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name=NAME,
    version=VERSION,
    description="Aspose.Imaging Cloud Python SDK",
    author="Sergei Zubov",
    author_email="sergei.zubov@aspose.com",
    url="https://products.aspose.cloud/imaging",
    licence="MIT",
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Multimedia :: Graphics',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords=[
        "Aspose",
        "Imaging",
        "Cloud",
        "REST",
        "API",
        "SDK",
        "image",
        "object detection",
        "reverse search",
        "image effects",
        "filters",
        "deskewing",
        "resize",
        "crop",
        "rotate",
        "convert",
        "metadata"
        "bmp",
        "dicom",
        "dng",
        "djvu",
        "djv",
        "emf",
        "gif",
        "jpg",
        "jpe",
        "jpeg",
        "jpeg2000",
        "jp2",
        "jpx",
        "jpm",
        "j2k",
        "odg",
        "png",
        "psd",
        "tiff",
        "tif",
        "webp",
        "wmf",
        "cdr",
        "cmx",
        "pdf",
        "svg",
        "otg"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "test*"]),
    include_package_data=True,
    data_files=[("", ["LICENSE"])],
    long_description=long_description,
    long_description_content_type="text/markdown"
)
